# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'ProjectIpWhiteList',
    'ProjectProperties',
    'ProjectPropertiesEncryption',
    'ProjectPropertiesTableLifecycle',
    'ProjectSecurityProperties',
    'ProjectSecurityPropertiesProjectProtection',
    'GetProjectsProjectResult',
    'GetProjectsProjectIpWhiteListResult',
    'GetProjectsProjectPropertiesResult',
    'GetProjectsProjectPropertiesEncryptionResult',
    'GetProjectsProjectPropertiesTableLifecycleResult',
    'GetProjectsProjectSecurityPropertiesResult',
    'GetProjectsProjectSecurityPropertiesProjectProtectionResult',
]

@pulumi.output_type
class ProjectIpWhiteList(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "ipList":
            suggest = "ip_list"
        elif key == "vpcIpList":
            suggest = "vpc_ip_list"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ProjectIpWhiteList. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ProjectIpWhiteList.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ProjectIpWhiteList.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 ip_list: Optional[str] = None,
                 vpc_ip_list: Optional[str] = None):
        """
        :param str ip_list: Set the IP address whitelist in the classic network. Only devices in the whitelist are allowed to access the project.> **NOTE:** If you only configure a classic network IP address whitelist, access to the classic network is restricted and all access to the VPC is prohibited.
        :param str vpc_ip_list: Set the IP address whitelist in the VPC network to allow only devices in the whitelist to access the project space.> **NOTE:** If you only configure a VPC network IP address whitelist, access to the VPC network is restricted and access to the classic network is prohibited.
        """
        if ip_list is not None:
            pulumi.set(__self__, "ip_list", ip_list)
        if vpc_ip_list is not None:
            pulumi.set(__self__, "vpc_ip_list", vpc_ip_list)

    @property
    @pulumi.getter(name="ipList")
    def ip_list(self) -> Optional[str]:
        """
        Set the IP address whitelist in the classic network. Only devices in the whitelist are allowed to access the project.> **NOTE:** If you only configure a classic network IP address whitelist, access to the classic network is restricted and all access to the VPC is prohibited.
        """
        return pulumi.get(self, "ip_list")

    @property
    @pulumi.getter(name="vpcIpList")
    def vpc_ip_list(self) -> Optional[str]:
        """
        Set the IP address whitelist in the VPC network to allow only devices in the whitelist to access the project space.> **NOTE:** If you only configure a VPC network IP address whitelist, access to the VPC network is restricted and access to the classic network is prohibited.
        """
        return pulumi.get(self, "vpc_ip_list")


@pulumi.output_type
class ProjectProperties(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "allowFullScan":
            suggest = "allow_full_scan"
        elif key == "enableDecimal2":
            suggest = "enable_decimal2"
        elif key == "retentionDays":
            suggest = "retention_days"
        elif key == "sqlMeteringMax":
            suggest = "sql_metering_max"
        elif key == "tableLifecycle":
            suggest = "table_lifecycle"
        elif key == "typeSystem":
            suggest = "type_system"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ProjectProperties. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ProjectProperties.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ProjectProperties.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 allow_full_scan: Optional[bool] = None,
                 enable_decimal2: Optional[bool] = None,
                 encryption: Optional['outputs.ProjectPropertiesEncryption'] = None,
                 retention_days: Optional[int] = None,
                 sql_metering_max: Optional[str] = None,
                 table_lifecycle: Optional['outputs.ProjectPropertiesTableLifecycle'] = None,
                 timezone: Optional[str] = None,
                 type_system: Optional[str] = None):
        """
        :param bool allow_full_scan: Whether to allow full table scan. Default: false.
        :param bool enable_decimal2: Whether to turn on Decimal2.0.
        :param 'ProjectPropertiesEncryptionArgs' encryption: Storage encryption. For details, see [Storage Encryption](https://www.alibabacloud.com/help/en/maxcompute/security-and-compliance/storage-encryption)
               > **NOTE :**:  To enable storage encryption, you need to modify the parameters of the basic attributes of the MaxCompute project. This operation permission is authenticated by RAM, and you need to have the Super_Administrator role permission of the corresponding project.  To configure the permissions and IP whitelist parameters of the MaxCompute project, you must have the management permissions (Admin) of the corresponding project, including Super_Administrator, Admin, or custom management permissions. For more information, see the project management permissions list.  You can turn on storage encryption only for projects that have not turned on storage encryption. For projects that have turned on storage encryption, you cannot turn off storage encryption or change the encryption algorithm. See `encryption` below.
        :param int retention_days: Set the number of days to retain backup data. During this time, you can restore the current version to any backup version. The value range of days is [0,30], and the default value is 1. 0 means backup is turned off. The effective policy after adjusting the backup cycle is: Extend the backup cycle: The new backup cycle takes effect on the same day. Shorten the backup cycle: The system will automatically delete backup data that has exceeded the retention cycle.
        :param str sql_metering_max: Set the maximum threshold of single SQL consumption, that is, set the ODPS. SQL. metering.value.max attribute. For details, see [Consumption Monitoring Alarm](https://www.alibabacloud.com/help/en/maxcompute/product-overview/consumption-control). Unit: scan volume (GB)* complexity. .
        :param 'ProjectPropertiesTableLifecycleArgs' table_lifecycle: Set whether the lifecycle of the table in the project needs to be configured, that is, set the ODPS. table.lifecycle property,. See `table_lifecycle` below.
        :param str timezone: Project time zone, example value: Asia/Shanghai.
        :param str type_system: Data type version. Value:(1/2/hive) 1: The original MaxCompute type system. 2: New type system introduced by MaxCompute 2.0. hive: the type system of the Hive compatibility mode introduced by MaxCompute 2.0.
        """
        if allow_full_scan is not None:
            pulumi.set(__self__, "allow_full_scan", allow_full_scan)
        if enable_decimal2 is not None:
            pulumi.set(__self__, "enable_decimal2", enable_decimal2)
        if encryption is not None:
            pulumi.set(__self__, "encryption", encryption)
        if retention_days is not None:
            pulumi.set(__self__, "retention_days", retention_days)
        if sql_metering_max is not None:
            pulumi.set(__self__, "sql_metering_max", sql_metering_max)
        if table_lifecycle is not None:
            pulumi.set(__self__, "table_lifecycle", table_lifecycle)
        if timezone is not None:
            pulumi.set(__self__, "timezone", timezone)
        if type_system is not None:
            pulumi.set(__self__, "type_system", type_system)

    @property
    @pulumi.getter(name="allowFullScan")
    def allow_full_scan(self) -> Optional[bool]:
        """
        Whether to allow full table scan. Default: false.
        """
        return pulumi.get(self, "allow_full_scan")

    @property
    @pulumi.getter(name="enableDecimal2")
    def enable_decimal2(self) -> Optional[bool]:
        """
        Whether to turn on Decimal2.0.
        """
        return pulumi.get(self, "enable_decimal2")

    @property
    @pulumi.getter
    def encryption(self) -> Optional['outputs.ProjectPropertiesEncryption']:
        """
        Storage encryption. For details, see [Storage Encryption](https://www.alibabacloud.com/help/en/maxcompute/security-and-compliance/storage-encryption)
        > **NOTE :**:  To enable storage encryption, you need to modify the parameters of the basic attributes of the MaxCompute project. This operation permission is authenticated by RAM, and you need to have the Super_Administrator role permission of the corresponding project.  To configure the permissions and IP whitelist parameters of the MaxCompute project, you must have the management permissions (Admin) of the corresponding project, including Super_Administrator, Admin, or custom management permissions. For more information, see the project management permissions list.  You can turn on storage encryption only for projects that have not turned on storage encryption. For projects that have turned on storage encryption, you cannot turn off storage encryption or change the encryption algorithm. See `encryption` below.
        """
        return pulumi.get(self, "encryption")

    @property
    @pulumi.getter(name="retentionDays")
    def retention_days(self) -> Optional[int]:
        """
        Set the number of days to retain backup data. During this time, you can restore the current version to any backup version. The value range of days is [0,30], and the default value is 1. 0 means backup is turned off. The effective policy after adjusting the backup cycle is: Extend the backup cycle: The new backup cycle takes effect on the same day. Shorten the backup cycle: The system will automatically delete backup data that has exceeded the retention cycle.
        """
        return pulumi.get(self, "retention_days")

    @property
    @pulumi.getter(name="sqlMeteringMax")
    def sql_metering_max(self) -> Optional[str]:
        """
        Set the maximum threshold of single SQL consumption, that is, set the ODPS. SQL. metering.value.max attribute. For details, see [Consumption Monitoring Alarm](https://www.alibabacloud.com/help/en/maxcompute/product-overview/consumption-control). Unit: scan volume (GB)* complexity. .
        """
        return pulumi.get(self, "sql_metering_max")

    @property
    @pulumi.getter(name="tableLifecycle")
    def table_lifecycle(self) -> Optional['outputs.ProjectPropertiesTableLifecycle']:
        """
        Set whether the lifecycle of the table in the project needs to be configured, that is, set the ODPS. table.lifecycle property,. See `table_lifecycle` below.
        """
        return pulumi.get(self, "table_lifecycle")

    @property
    @pulumi.getter
    def timezone(self) -> Optional[str]:
        """
        Project time zone, example value: Asia/Shanghai.
        """
        return pulumi.get(self, "timezone")

    @property
    @pulumi.getter(name="typeSystem")
    def type_system(self) -> Optional[str]:
        """
        Data type version. Value:(1/2/hive) 1: The original MaxCompute type system. 2: New type system introduced by MaxCompute 2.0. hive: the type system of the Hive compatibility mode introduced by MaxCompute 2.0.
        """
        return pulumi.get(self, "type_system")


@pulumi.output_type
class ProjectPropertiesEncryption(dict):
    def __init__(__self__, *,
                 algorithm: Optional[str] = None,
                 enable: Optional[bool] = None,
                 key: Optional[str] = None):
        """
        :param str algorithm: The encryption algorithm supported by the key, including AES256, AESCTR, and RC4.
        :param bool enable: Only enable function is supported. Value: (true).
        :param str key: The encryption algorithm Key, the Key type used by the project, including the Default Key (MaxCompute Default Key) and the self-contained Key (BYOK). The MaxCompute Default Key is the Default Key created inside MaxCompute.
        """
        if algorithm is not None:
            pulumi.set(__self__, "algorithm", algorithm)
        if enable is not None:
            pulumi.set(__self__, "enable", enable)
        if key is not None:
            pulumi.set(__self__, "key", key)

    @property
    @pulumi.getter
    def algorithm(self) -> Optional[str]:
        """
        The encryption algorithm supported by the key, including AES256, AESCTR, and RC4.
        """
        return pulumi.get(self, "algorithm")

    @property
    @pulumi.getter
    def enable(self) -> Optional[bool]:
        """
        Only enable function is supported. Value: (true).
        """
        return pulumi.get(self, "enable")

    @property
    @pulumi.getter
    def key(self) -> Optional[str]:
        """
        The encryption algorithm Key, the Key type used by the project, including the Default Key (MaxCompute Default Key) and the self-contained Key (BYOK). The MaxCompute Default Key is the Default Key created inside MaxCompute.
        """
        return pulumi.get(self, "key")


@pulumi.output_type
class ProjectPropertiesTableLifecycle(dict):
    def __init__(__self__, *,
                 type: Optional[str] = None,
                 value: Optional[str] = None):
        """
        :param str type: Project type
        :param str value: The value of the life cycle, in days. The value range is 1~37231, and the default value is 37231.
        """
        if type is not None:
            pulumi.set(__self__, "type", type)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[str]:
        """
        Project type
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def value(self) -> Optional[str]:
        """
        The value of the life cycle, in days. The value range is 1~37231, and the default value is 37231.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class ProjectSecurityProperties(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "enableDownloadPrivilege":
            suggest = "enable_download_privilege"
        elif key == "labelSecurity":
            suggest = "label_security"
        elif key == "objectCreatorHasAccessPermission":
            suggest = "object_creator_has_access_permission"
        elif key == "objectCreatorHasGrantPermission":
            suggest = "object_creator_has_grant_permission"
        elif key == "projectProtection":
            suggest = "project_protection"
        elif key == "usingAcl":
            suggest = "using_acl"
        elif key == "usingPolicy":
            suggest = "using_policy"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ProjectSecurityProperties. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ProjectSecurityProperties.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ProjectSecurityProperties.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 enable_download_privilege: Optional[bool] = None,
                 label_security: Optional[bool] = None,
                 object_creator_has_access_permission: Optional[bool] = None,
                 object_creator_has_grant_permission: Optional[bool] = None,
                 project_protection: Optional['outputs.ProjectSecurityPropertiesProjectProtection'] = None,
                 using_acl: Optional[bool] = None,
                 using_policy: Optional[bool] = None):
        """
        :param bool enable_download_privilege: Set whether to enable the [Download permission control function](https://www.alibabacloud.com/help/en/maxcompute/user-guide/download-control), that is, set the ODPS. security.enabledownloadprivilege property.
        :param bool label_security: Set whether to use the [Label permission control function](https://www.alibabacloud.com/help/en/maxcompute/user-guide/label-based-access-control), that is, set the LabelSecurity attribute, which is not used by default.
        :param bool object_creator_has_access_permission: Sets whether to allow the creator of the object to have access to the object, I .e. sets the attribute. The default is the allowed state.
        :param bool object_creator_has_grant_permission: The ObjectCreatorHasGrantPermission attribute is set to allow the object creator to have the authorization permission on the object. The default is the allowed state.
        :param 'ProjectSecurityPropertiesProjectProtectionArgs' project_protection: Project protection. See `project_protection` below.
        :param bool using_acl: Set whether to use the [ACL permission control function](https://www.alibabacloud.com/help/en/maxcompute/user-guide/maxcompute-permissions), that is, set the CheckPermissionUsingACL attribute, which is in use by default.
        :param bool using_policy: Set whether to use the Policy permission control function (https://www.alibabacloud.com/help/en/maxcompute/user-guide/policy-based-access-control-1), that is, set the CheckPermissionUsingACL attribute, which is in use by default.
        """
        if enable_download_privilege is not None:
            pulumi.set(__self__, "enable_download_privilege", enable_download_privilege)
        if label_security is not None:
            pulumi.set(__self__, "label_security", label_security)
        if object_creator_has_access_permission is not None:
            pulumi.set(__self__, "object_creator_has_access_permission", object_creator_has_access_permission)
        if object_creator_has_grant_permission is not None:
            pulumi.set(__self__, "object_creator_has_grant_permission", object_creator_has_grant_permission)
        if project_protection is not None:
            pulumi.set(__self__, "project_protection", project_protection)
        if using_acl is not None:
            pulumi.set(__self__, "using_acl", using_acl)
        if using_policy is not None:
            pulumi.set(__self__, "using_policy", using_policy)

    @property
    @pulumi.getter(name="enableDownloadPrivilege")
    def enable_download_privilege(self) -> Optional[bool]:
        """
        Set whether to enable the [Download permission control function](https://www.alibabacloud.com/help/en/maxcompute/user-guide/download-control), that is, set the ODPS. security.enabledownloadprivilege property.
        """
        return pulumi.get(self, "enable_download_privilege")

    @property
    @pulumi.getter(name="labelSecurity")
    def label_security(self) -> Optional[bool]:
        """
        Set whether to use the [Label permission control function](https://www.alibabacloud.com/help/en/maxcompute/user-guide/label-based-access-control), that is, set the LabelSecurity attribute, which is not used by default.
        """
        return pulumi.get(self, "label_security")

    @property
    @pulumi.getter(name="objectCreatorHasAccessPermission")
    def object_creator_has_access_permission(self) -> Optional[bool]:
        """
        Sets whether to allow the creator of the object to have access to the object, I .e. sets the attribute. The default is the allowed state.
        """
        return pulumi.get(self, "object_creator_has_access_permission")

    @property
    @pulumi.getter(name="objectCreatorHasGrantPermission")
    def object_creator_has_grant_permission(self) -> Optional[bool]:
        """
        The ObjectCreatorHasGrantPermission attribute is set to allow the object creator to have the authorization permission on the object. The default is the allowed state.
        """
        return pulumi.get(self, "object_creator_has_grant_permission")

    @property
    @pulumi.getter(name="projectProtection")
    def project_protection(self) -> Optional['outputs.ProjectSecurityPropertiesProjectProtection']:
        """
        Project protection. See `project_protection` below.
        """
        return pulumi.get(self, "project_protection")

    @property
    @pulumi.getter(name="usingAcl")
    def using_acl(self) -> Optional[bool]:
        """
        Set whether to use the [ACL permission control function](https://www.alibabacloud.com/help/en/maxcompute/user-guide/maxcompute-permissions), that is, set the CheckPermissionUsingACL attribute, which is in use by default.
        """
        return pulumi.get(self, "using_acl")

    @property
    @pulumi.getter(name="usingPolicy")
    def using_policy(self) -> Optional[bool]:
        """
        Set whether to use the Policy permission control function (https://www.alibabacloud.com/help/en/maxcompute/user-guide/policy-based-access-control-1), that is, set the CheckPermissionUsingACL attribute, which is in use by default.
        """
        return pulumi.get(self, "using_policy")


@pulumi.output_type
class ProjectSecurityPropertiesProjectProtection(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "exceptionPolicy":
            suggest = "exception_policy"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ProjectSecurityPropertiesProjectProtection. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ProjectSecurityPropertiesProjectProtection.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ProjectSecurityPropertiesProjectProtection.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 exception_policy: Optional[str] = None,
                 protected: Optional[bool] = None):
        """
        :param str exception_policy: Set [Exceptions or Trusted Items](https://www.alibabacloud.com/help/en/maxcompute/security-and-compliance/project-data-protection).
        :param bool protected: Whether enabled, value:(true/false).
        """
        if exception_policy is not None:
            pulumi.set(__self__, "exception_policy", exception_policy)
        if protected is not None:
            pulumi.set(__self__, "protected", protected)

    @property
    @pulumi.getter(name="exceptionPolicy")
    def exception_policy(self) -> Optional[str]:
        """
        Set [Exceptions or Trusted Items](https://www.alibabacloud.com/help/en/maxcompute/security-and-compliance/project-data-protection).
        """
        return pulumi.get(self, "exception_policy")

    @property
    @pulumi.getter
    def protected(self) -> Optional[bool]:
        """
        Whether enabled, value:(true/false).
        """
        return pulumi.get(self, "protected")


@pulumi.output_type
class GetProjectsProjectResult(dict):
    def __init__(__self__, *,
                 comment: str,
                 cost_storage: str,
                 create_time: str,
                 default_quota: str,
                 ip_white_list: 'outputs.GetProjectsProjectIpWhiteListResult',
                 owner: str,
                 project_name: str,
                 properties: 'outputs.GetProjectsProjectPropertiesResult',
                 security_properties: 'outputs.GetProjectsProjectSecurityPropertiesResult',
                 status: str,
                 type: str):
        """
        :param str comment: Project description information. The length is 1 to 256 English or Chinese characters. The default value is blank.
        :param str cost_storage: View the current storage size of the Project. The storage size is the same as the measurement size, that is, the compressed logical storage size collected by the Project.
        :param str create_time: Represents the creation time of the project
        :param str default_quota: Used to implement computing resource allocation.If the calculation Quota is not specified, the default Quota resource will be consumed by jobs initiated by the project. For more information about computing resource usage, see [Computing Resource Usage](https://www.alibabacloud.com/help/en/maxcompute/user-guide/use-of-computing-resources).
        :param 'GetProjectsProjectIpWhiteListArgs' ip_white_list: IP whitelist
        :param str owner: Project owner
        :param str project_name: The name begins with a letter, containing letters, digits, and underscores (_). It can be 3 to 28 characters in length and is globally unique.
        :param 'GetProjectsProjectPropertiesArgs' properties: Project base attributes
        :param 'GetProjectsProjectSecurityPropertiesArgs' security_properties: Security-related attributes
        :param str status: The project status. Default value: AVAILABLE. Value: (AVAILABLE/READONLY/FROZEN/DELETING)
        :param str type: Project type
        """
        pulumi.set(__self__, "comment", comment)
        pulumi.set(__self__, "cost_storage", cost_storage)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "default_quota", default_quota)
        pulumi.set(__self__, "ip_white_list", ip_white_list)
        pulumi.set(__self__, "owner", owner)
        pulumi.set(__self__, "project_name", project_name)
        pulumi.set(__self__, "properties", properties)
        pulumi.set(__self__, "security_properties", security_properties)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def comment(self) -> str:
        """
        Project description information. The length is 1 to 256 English or Chinese characters. The default value is blank.
        """
        return pulumi.get(self, "comment")

    @property
    @pulumi.getter(name="costStorage")
    def cost_storage(self) -> str:
        """
        View the current storage size of the Project. The storage size is the same as the measurement size, that is, the compressed logical storage size collected by the Project.
        """
        return pulumi.get(self, "cost_storage")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        Represents the creation time of the project
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="defaultQuota")
    def default_quota(self) -> str:
        """
        Used to implement computing resource allocation.If the calculation Quota is not specified, the default Quota resource will be consumed by jobs initiated by the project. For more information about computing resource usage, see [Computing Resource Usage](https://www.alibabacloud.com/help/en/maxcompute/user-guide/use-of-computing-resources).
        """
        return pulumi.get(self, "default_quota")

    @property
    @pulumi.getter(name="ipWhiteList")
    def ip_white_list(self) -> 'outputs.GetProjectsProjectIpWhiteListResult':
        """
        IP whitelist
        """
        return pulumi.get(self, "ip_white_list")

    @property
    @pulumi.getter
    def owner(self) -> str:
        """
        Project owner
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> str:
        """
        The name begins with a letter, containing letters, digits, and underscores (_). It can be 3 to 28 characters in length and is globally unique.
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def properties(self) -> 'outputs.GetProjectsProjectPropertiesResult':
        """
        Project base attributes
        """
        return pulumi.get(self, "properties")

    @property
    @pulumi.getter(name="securityProperties")
    def security_properties(self) -> 'outputs.GetProjectsProjectSecurityPropertiesResult':
        """
        Security-related attributes
        """
        return pulumi.get(self, "security_properties")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The project status. Default value: AVAILABLE. Value: (AVAILABLE/READONLY/FROZEN/DELETING)
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        Project type
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class GetProjectsProjectIpWhiteListResult(dict):
    def __init__(__self__, *,
                 ip_list: str,
                 vpc_ip_list: str):
        """
        :param str ip_list: Set the IP address whitelist in the classic network. Only devices in the whitelist are allowed to access the project.> **NOTE:** If you only configure a classic network IP address whitelist, access to the classic network is restricted and all access to the VPC is prohibited.
        :param str vpc_ip_list: Set the IP address whitelist in the VPC network to allow only devices in the whitelist to access the project space.> **NOTE:** If you only configure a VPC network IP address whitelist, access to the VPC network is restricted and access to the classic network is prohibited.
        """
        pulumi.set(__self__, "ip_list", ip_list)
        pulumi.set(__self__, "vpc_ip_list", vpc_ip_list)

    @property
    @pulumi.getter(name="ipList")
    def ip_list(self) -> str:
        """
        Set the IP address whitelist in the classic network. Only devices in the whitelist are allowed to access the project.> **NOTE:** If you only configure a classic network IP address whitelist, access to the classic network is restricted and all access to the VPC is prohibited.
        """
        return pulumi.get(self, "ip_list")

    @property
    @pulumi.getter(name="vpcIpList")
    def vpc_ip_list(self) -> str:
        """
        Set the IP address whitelist in the VPC network to allow only devices in the whitelist to access the project space.> **NOTE:** If you only configure a VPC network IP address whitelist, access to the VPC network is restricted and access to the classic network is prohibited.
        """
        return pulumi.get(self, "vpc_ip_list")


@pulumi.output_type
class GetProjectsProjectPropertiesResult(dict):
    def __init__(__self__, *,
                 allow_full_scan: bool,
                 enable_decimal2: bool,
                 encryption: 'outputs.GetProjectsProjectPropertiesEncryptionResult',
                 retention_days: int,
                 sql_metering_max: str,
                 table_lifecycle: 'outputs.GetProjectsProjectPropertiesTableLifecycleResult',
                 timezone: str,
                 type_system: str):
        """
        :param bool allow_full_scan: Whether to allow full table scan. Default: false.
        :param bool enable_decimal2: Whether to turn on Decimal2.0.
        :param 'GetProjectsProjectPropertiesEncryptionArgs' encryption: Storage encryption. For details, see [Storage Encryption](https://www.alibabacloud.com/help/en/maxcompute/security-and-compliance/storage-encryption)> **NOTE :**:To enable storage encryption, you need to modify the parameters of the basic attributes of the MaxCompute project. This operation permission is authenticated by RAM, and you need to have the Super_Administrator role permission of the corresponding project.To configure the permissions and IP whitelist parameters of the MaxCompute project, you must have the management permissions (Admin) of the corresponding project, including Super_Administrator, Admin, or custom management permissions. For more information, see the project management permissions list.You can turn on storage encryption only for projects that have not turned on storage encryption. For projects that have turned on storage encryption, you cannot turn off storage encryption or change the encryption algorithm.
        :param int retention_days: Set the number of days to retain backup data. During this time, you can restore the current version to any backup version. The value range of days is [0,30], and the default value is 1. 0 means backup is turned off.The effective policy after adjusting the backup cycle is:Extend the backup cycle: The new backup cycle takes effect on the same day.Shorten the backup cycle: The system will automatically delete backup data that has exceeded the retention cycle.
        :param str sql_metering_max: Set the maximum threshold of single SQL consumption, that is, set the ODPS. SQL. metering.value.max attribute. For details, see [Consumption Monitoring Alarm](https://www.alibabacloud.com/help/en/maxcompute/product-overview/consumption-control).Unit: scan volume (GB)* complexity.
        :param 'GetProjectsProjectPropertiesTableLifecycleArgs' table_lifecycle: Set whether the lifecycle of the table in the project needs to be configured, that is, set the ODPS. table.lifecycle property,.
        :param str timezone: Project time zone, example value: Asia/Shanghai.
        :param str type_system: Data type version. Value:(1/2/hive)1: The original MaxCompute type system.2: New type system introduced by MaxCompute 2.0.hive: the type system of the Hive compatibility mode introduced by MaxCompute 2.0.
        """
        pulumi.set(__self__, "allow_full_scan", allow_full_scan)
        pulumi.set(__self__, "enable_decimal2", enable_decimal2)
        pulumi.set(__self__, "encryption", encryption)
        pulumi.set(__self__, "retention_days", retention_days)
        pulumi.set(__self__, "sql_metering_max", sql_metering_max)
        pulumi.set(__self__, "table_lifecycle", table_lifecycle)
        pulumi.set(__self__, "timezone", timezone)
        pulumi.set(__self__, "type_system", type_system)

    @property
    @pulumi.getter(name="allowFullScan")
    def allow_full_scan(self) -> bool:
        """
        Whether to allow full table scan. Default: false.
        """
        return pulumi.get(self, "allow_full_scan")

    @property
    @pulumi.getter(name="enableDecimal2")
    def enable_decimal2(self) -> bool:
        """
        Whether to turn on Decimal2.0.
        """
        return pulumi.get(self, "enable_decimal2")

    @property
    @pulumi.getter
    def encryption(self) -> 'outputs.GetProjectsProjectPropertiesEncryptionResult':
        """
        Storage encryption. For details, see [Storage Encryption](https://www.alibabacloud.com/help/en/maxcompute/security-and-compliance/storage-encryption)> **NOTE :**:To enable storage encryption, you need to modify the parameters of the basic attributes of the MaxCompute project. This operation permission is authenticated by RAM, and you need to have the Super_Administrator role permission of the corresponding project.To configure the permissions and IP whitelist parameters of the MaxCompute project, you must have the management permissions (Admin) of the corresponding project, including Super_Administrator, Admin, or custom management permissions. For more information, see the project management permissions list.You can turn on storage encryption only for projects that have not turned on storage encryption. For projects that have turned on storage encryption, you cannot turn off storage encryption or change the encryption algorithm.
        """
        return pulumi.get(self, "encryption")

    @property
    @pulumi.getter(name="retentionDays")
    def retention_days(self) -> int:
        """
        Set the number of days to retain backup data. During this time, you can restore the current version to any backup version. The value range of days is [0,30], and the default value is 1. 0 means backup is turned off.The effective policy after adjusting the backup cycle is:Extend the backup cycle: The new backup cycle takes effect on the same day.Shorten the backup cycle: The system will automatically delete backup data that has exceeded the retention cycle.
        """
        return pulumi.get(self, "retention_days")

    @property
    @pulumi.getter(name="sqlMeteringMax")
    def sql_metering_max(self) -> str:
        """
        Set the maximum threshold of single SQL consumption, that is, set the ODPS. SQL. metering.value.max attribute. For details, see [Consumption Monitoring Alarm](https://www.alibabacloud.com/help/en/maxcompute/product-overview/consumption-control).Unit: scan volume (GB)* complexity.
        """
        return pulumi.get(self, "sql_metering_max")

    @property
    @pulumi.getter(name="tableLifecycle")
    def table_lifecycle(self) -> 'outputs.GetProjectsProjectPropertiesTableLifecycleResult':
        """
        Set whether the lifecycle of the table in the project needs to be configured, that is, set the ODPS. table.lifecycle property,.
        """
        return pulumi.get(self, "table_lifecycle")

    @property
    @pulumi.getter
    def timezone(self) -> str:
        """
        Project time zone, example value: Asia/Shanghai.
        """
        return pulumi.get(self, "timezone")

    @property
    @pulumi.getter(name="typeSystem")
    def type_system(self) -> str:
        """
        Data type version. Value:(1/2/hive)1: The original MaxCompute type system.2: New type system introduced by MaxCompute 2.0.hive: the type system of the Hive compatibility mode introduced by MaxCompute 2.0.
        """
        return pulumi.get(self, "type_system")


@pulumi.output_type
class GetProjectsProjectPropertiesEncryptionResult(dict):
    def __init__(__self__, *,
                 algorithm: str,
                 enable: bool,
                 key: str):
        """
        :param str algorithm: The encryption algorithm supported by the key, including AES256, AESCTR, and RC4.
        :param bool enable: Only enable function is supported. Value: (true).
        :param str key: The encryption algorithm Key, the Key type used by the project, including the Default Key (MaxCompute Default Key) and the self-contained Key (BYOK). The MaxCompute Default Key is the Default Key created inside MaxCompute.
        """
        pulumi.set(__self__, "algorithm", algorithm)
        pulumi.set(__self__, "enable", enable)
        pulumi.set(__self__, "key", key)

    @property
    @pulumi.getter
    def algorithm(self) -> str:
        """
        The encryption algorithm supported by the key, including AES256, AESCTR, and RC4.
        """
        return pulumi.get(self, "algorithm")

    @property
    @pulumi.getter
    def enable(self) -> bool:
        """
        Only enable function is supported. Value: (true).
        """
        return pulumi.get(self, "enable")

    @property
    @pulumi.getter
    def key(self) -> str:
        """
        The encryption algorithm Key, the Key type used by the project, including the Default Key (MaxCompute Default Key) and the self-contained Key (BYOK). The MaxCompute Default Key is the Default Key created inside MaxCompute.
        """
        return pulumi.get(self, "key")


@pulumi.output_type
class GetProjectsProjectPropertiesTableLifecycleResult(dict):
    def __init__(__self__, *,
                 type: str,
                 value: str):
        """
        :param str type: Project type
        :param str value: The value of the life cycle, in days. The value range is 1~37231, and the default value is 37231.
        """
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        Project type
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        The value of the life cycle, in days. The value range is 1~37231, and the default value is 37231.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetProjectsProjectSecurityPropertiesResult(dict):
    def __init__(__self__, *,
                 enable_download_privilege: bool,
                 label_security: bool,
                 object_creator_has_access_permission: bool,
                 object_creator_has_grant_permission: bool,
                 project_protection: 'outputs.GetProjectsProjectSecurityPropertiesProjectProtectionResult',
                 using_acl: bool,
                 using_policy: bool):
        """
        :param bool enable_download_privilege: Set whether to enable the [Download permission control function](https://www.alibabacloud.com/help/en/maxcompute/user-guide/download-control), that is, set the ODPS. security.enabledownloadprivilege property.
        :param bool label_security: Set whether to use the [Label permission control function](https://www.alibabacloud.com/help/en/maxcompute/user-guide/label-based-access-control), that is, set the LabelSecurity attribute, which is not used by default.
        :param bool object_creator_has_access_permission: Sets whether to allow the creator of the object to have access to the object, I .e. sets the attribute. The default is the allowed state.
        :param bool object_creator_has_grant_permission: The ObjectCreatorHasGrantPermission attribute is set to allow the object creator to have the authorization permission on the object. The default is the allowed state.
        :param 'GetProjectsProjectSecurityPropertiesProjectProtectionArgs' project_protection: Project protection.
        :param bool using_acl: Set whether to use the [ACL permission control function](https://www.alibabacloud.com/help/en/maxcompute/user-guide/maxcompute-permissions), that is, set the CheckPermissionUsingACL attribute, which is in use by default.
        :param bool using_policy: Set whether to use the Policy permission control function (https://www.alibabacloud.com/help/en/maxcompute/user-guide/policy-based-access-control-1), that is, set the CheckPermissionUsingACL attribute, which is in use by default.
        """
        pulumi.set(__self__, "enable_download_privilege", enable_download_privilege)
        pulumi.set(__self__, "label_security", label_security)
        pulumi.set(__self__, "object_creator_has_access_permission", object_creator_has_access_permission)
        pulumi.set(__self__, "object_creator_has_grant_permission", object_creator_has_grant_permission)
        pulumi.set(__self__, "project_protection", project_protection)
        pulumi.set(__self__, "using_acl", using_acl)
        pulumi.set(__self__, "using_policy", using_policy)

    @property
    @pulumi.getter(name="enableDownloadPrivilege")
    def enable_download_privilege(self) -> bool:
        """
        Set whether to enable the [Download permission control function](https://www.alibabacloud.com/help/en/maxcompute/user-guide/download-control), that is, set the ODPS. security.enabledownloadprivilege property.
        """
        return pulumi.get(self, "enable_download_privilege")

    @property
    @pulumi.getter(name="labelSecurity")
    def label_security(self) -> bool:
        """
        Set whether to use the [Label permission control function](https://www.alibabacloud.com/help/en/maxcompute/user-guide/label-based-access-control), that is, set the LabelSecurity attribute, which is not used by default.
        """
        return pulumi.get(self, "label_security")

    @property
    @pulumi.getter(name="objectCreatorHasAccessPermission")
    def object_creator_has_access_permission(self) -> bool:
        """
        Sets whether to allow the creator of the object to have access to the object, I .e. sets the attribute. The default is the allowed state.
        """
        return pulumi.get(self, "object_creator_has_access_permission")

    @property
    @pulumi.getter(name="objectCreatorHasGrantPermission")
    def object_creator_has_grant_permission(self) -> bool:
        """
        The ObjectCreatorHasGrantPermission attribute is set to allow the object creator to have the authorization permission on the object. The default is the allowed state.
        """
        return pulumi.get(self, "object_creator_has_grant_permission")

    @property
    @pulumi.getter(name="projectProtection")
    def project_protection(self) -> 'outputs.GetProjectsProjectSecurityPropertiesProjectProtectionResult':
        """
        Project protection.
        """
        return pulumi.get(self, "project_protection")

    @property
    @pulumi.getter(name="usingAcl")
    def using_acl(self) -> bool:
        """
        Set whether to use the [ACL permission control function](https://www.alibabacloud.com/help/en/maxcompute/user-guide/maxcompute-permissions), that is, set the CheckPermissionUsingACL attribute, which is in use by default.
        """
        return pulumi.get(self, "using_acl")

    @property
    @pulumi.getter(name="usingPolicy")
    def using_policy(self) -> bool:
        """
        Set whether to use the Policy permission control function (https://www.alibabacloud.com/help/en/maxcompute/user-guide/policy-based-access-control-1), that is, set the CheckPermissionUsingACL attribute, which is in use by default.
        """
        return pulumi.get(self, "using_policy")


@pulumi.output_type
class GetProjectsProjectSecurityPropertiesProjectProtectionResult(dict):
    def __init__(__self__, *,
                 exception_policy: str,
                 protected: bool):
        """
        :param str exception_policy: Set [Exceptions or Trusted Items](https://www.alibabacloud.com/help/en/maxcompute/security-and-compliance/project-data-protection).
        :param bool protected: Whether enabled, value:(true/false).
        """
        pulumi.set(__self__, "exception_policy", exception_policy)
        pulumi.set(__self__, "protected", protected)

    @property
    @pulumi.getter(name="exceptionPolicy")
    def exception_policy(self) -> str:
        """
        Set [Exceptions or Trusted Items](https://www.alibabacloud.com/help/en/maxcompute/security-and-compliance/project-data-protection).
        """
        return pulumi.get(self, "exception_policy")

    @property
    @pulumi.getter
    def protected(self) -> bool:
        """
        Whether enabled, value:(true/false).
        """
        return pulumi.get(self, "protected")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['FcTriggerArgs', 'FcTrigger']

@pulumi.input_type
class FcTriggerArgs:
    def __init__(__self__, *,
                 event_meta_name: pulumi.Input[str],
                 event_meta_version: pulumi.Input[str],
                 notes: pulumi.Input[str],
                 role_arn: pulumi.Input[str],
                 source_arn: pulumi.Input[str],
                 trigger_arn: pulumi.Input[str],
                 function_arn: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a FcTrigger resource.
        :param pulumi.Input[str] event_meta_name: The name of the Event.
        :param pulumi.Input[str] event_meta_version: The version of the Event.
        :param pulumi.Input[str] notes: The Note information.
        :param pulumi.Input[str] role_arn: The role authorized by RAM. The value formats as `acs:ram::{AccountID}:role/{RoleName}`.
        :param pulumi.Input[str] source_arn: Resources and filters for event listening. The value formats as `acs:cdn:{RegionID}:{AccountID}:{Filter}`.
        :param pulumi.Input[str] trigger_arn: The trigger corresponding to the function Compute Service. The value formats as `acs:fc:{RegionID}:{AccountID}:{Filter}`. See [Create a CDN Fc Trigger](https://www.alibabacloud.com/help/en/cdn/developer-reference/api-cdn-2018-05-10-addfctrigger) for more details.
        :param pulumi.Input[str] function_arn: The function arn. The value formats as `acs:fc:{RegionID}:{AccountID}:{Filter}`.
        """
        pulumi.set(__self__, "event_meta_name", event_meta_name)
        pulumi.set(__self__, "event_meta_version", event_meta_version)
        pulumi.set(__self__, "notes", notes)
        pulumi.set(__self__, "role_arn", role_arn)
        pulumi.set(__self__, "source_arn", source_arn)
        pulumi.set(__self__, "trigger_arn", trigger_arn)
        if function_arn is not None:
            pulumi.set(__self__, "function_arn", function_arn)

    @property
    @pulumi.getter(name="eventMetaName")
    def event_meta_name(self) -> pulumi.Input[str]:
        """
        The name of the Event.
        """
        return pulumi.get(self, "event_meta_name")

    @event_meta_name.setter
    def event_meta_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "event_meta_name", value)

    @property
    @pulumi.getter(name="eventMetaVersion")
    def event_meta_version(self) -> pulumi.Input[str]:
        """
        The version of the Event.
        """
        return pulumi.get(self, "event_meta_version")

    @event_meta_version.setter
    def event_meta_version(self, value: pulumi.Input[str]):
        pulumi.set(self, "event_meta_version", value)

    @property
    @pulumi.getter
    def notes(self) -> pulumi.Input[str]:
        """
        The Note information.
        """
        return pulumi.get(self, "notes")

    @notes.setter
    def notes(self, value: pulumi.Input[str]):
        pulumi.set(self, "notes", value)

    @property
    @pulumi.getter(name="roleArn")
    def role_arn(self) -> pulumi.Input[str]:
        """
        The role authorized by RAM. The value formats as `acs:ram::{AccountID}:role/{RoleName}`.
        """
        return pulumi.get(self, "role_arn")

    @role_arn.setter
    def role_arn(self, value: pulumi.Input[str]):
        pulumi.set(self, "role_arn", value)

    @property
    @pulumi.getter(name="sourceArn")
    def source_arn(self) -> pulumi.Input[str]:
        """
        Resources and filters for event listening. The value formats as `acs:cdn:{RegionID}:{AccountID}:{Filter}`.
        """
        return pulumi.get(self, "source_arn")

    @source_arn.setter
    def source_arn(self, value: pulumi.Input[str]):
        pulumi.set(self, "source_arn", value)

    @property
    @pulumi.getter(name="triggerArn")
    def trigger_arn(self) -> pulumi.Input[str]:
        """
        The trigger corresponding to the function Compute Service. The value formats as `acs:fc:{RegionID}:{AccountID}:{Filter}`. See [Create a CDN Fc Trigger](https://www.alibabacloud.com/help/en/cdn/developer-reference/api-cdn-2018-05-10-addfctrigger) for more details.
        """
        return pulumi.get(self, "trigger_arn")

    @trigger_arn.setter
    def trigger_arn(self, value: pulumi.Input[str]):
        pulumi.set(self, "trigger_arn", value)

    @property
    @pulumi.getter(name="functionArn")
    def function_arn(self) -> Optional[pulumi.Input[str]]:
        """
        The function arn. The value formats as `acs:fc:{RegionID}:{AccountID}:{Filter}`.
        """
        return pulumi.get(self, "function_arn")

    @function_arn.setter
    def function_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "function_arn", value)


@pulumi.input_type
class _FcTriggerState:
    def __init__(__self__, *,
                 event_meta_name: Optional[pulumi.Input[str]] = None,
                 event_meta_version: Optional[pulumi.Input[str]] = None,
                 function_arn: Optional[pulumi.Input[str]] = None,
                 notes: Optional[pulumi.Input[str]] = None,
                 role_arn: Optional[pulumi.Input[str]] = None,
                 source_arn: Optional[pulumi.Input[str]] = None,
                 trigger_arn: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering FcTrigger resources.
        :param pulumi.Input[str] event_meta_name: The name of the Event.
        :param pulumi.Input[str] event_meta_version: The version of the Event.
        :param pulumi.Input[str] function_arn: The function arn. The value formats as `acs:fc:{RegionID}:{AccountID}:{Filter}`.
        :param pulumi.Input[str] notes: The Note information.
        :param pulumi.Input[str] role_arn: The role authorized by RAM. The value formats as `acs:ram::{AccountID}:role/{RoleName}`.
        :param pulumi.Input[str] source_arn: Resources and filters for event listening. The value formats as `acs:cdn:{RegionID}:{AccountID}:{Filter}`.
        :param pulumi.Input[str] trigger_arn: The trigger corresponding to the function Compute Service. The value formats as `acs:fc:{RegionID}:{AccountID}:{Filter}`. See [Create a CDN Fc Trigger](https://www.alibabacloud.com/help/en/cdn/developer-reference/api-cdn-2018-05-10-addfctrigger) for more details.
        """
        if event_meta_name is not None:
            pulumi.set(__self__, "event_meta_name", event_meta_name)
        if event_meta_version is not None:
            pulumi.set(__self__, "event_meta_version", event_meta_version)
        if function_arn is not None:
            pulumi.set(__self__, "function_arn", function_arn)
        if notes is not None:
            pulumi.set(__self__, "notes", notes)
        if role_arn is not None:
            pulumi.set(__self__, "role_arn", role_arn)
        if source_arn is not None:
            pulumi.set(__self__, "source_arn", source_arn)
        if trigger_arn is not None:
            pulumi.set(__self__, "trigger_arn", trigger_arn)

    @property
    @pulumi.getter(name="eventMetaName")
    def event_meta_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Event.
        """
        return pulumi.get(self, "event_meta_name")

    @event_meta_name.setter
    def event_meta_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "event_meta_name", value)

    @property
    @pulumi.getter(name="eventMetaVersion")
    def event_meta_version(self) -> Optional[pulumi.Input[str]]:
        """
        The version of the Event.
        """
        return pulumi.get(self, "event_meta_version")

    @event_meta_version.setter
    def event_meta_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "event_meta_version", value)

    @property
    @pulumi.getter(name="functionArn")
    def function_arn(self) -> Optional[pulumi.Input[str]]:
        """
        The function arn. The value formats as `acs:fc:{RegionID}:{AccountID}:{Filter}`.
        """
        return pulumi.get(self, "function_arn")

    @function_arn.setter
    def function_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "function_arn", value)

    @property
    @pulumi.getter
    def notes(self) -> Optional[pulumi.Input[str]]:
        """
        The Note information.
        """
        return pulumi.get(self, "notes")

    @notes.setter
    def notes(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "notes", value)

    @property
    @pulumi.getter(name="roleArn")
    def role_arn(self) -> Optional[pulumi.Input[str]]:
        """
        The role authorized by RAM. The value formats as `acs:ram::{AccountID}:role/{RoleName}`.
        """
        return pulumi.get(self, "role_arn")

    @role_arn.setter
    def role_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "role_arn", value)

    @property
    @pulumi.getter(name="sourceArn")
    def source_arn(self) -> Optional[pulumi.Input[str]]:
        """
        Resources and filters for event listening. The value formats as `acs:cdn:{RegionID}:{AccountID}:{Filter}`.
        """
        return pulumi.get(self, "source_arn")

    @source_arn.setter
    def source_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_arn", value)

    @property
    @pulumi.getter(name="triggerArn")
    def trigger_arn(self) -> Optional[pulumi.Input[str]]:
        """
        The trigger corresponding to the function Compute Service. The value formats as `acs:fc:{RegionID}:{AccountID}:{Filter}`. See [Create a CDN Fc Trigger](https://www.alibabacloud.com/help/en/cdn/developer-reference/api-cdn-2018-05-10-addfctrigger) for more details.
        """
        return pulumi.get(self, "trigger_arn")

    @trigger_arn.setter
    def trigger_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "trigger_arn", value)


class FcTrigger(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 event_meta_name: Optional[pulumi.Input[str]] = None,
                 event_meta_version: Optional[pulumi.Input[str]] = None,
                 function_arn: Optional[pulumi.Input[str]] = None,
                 notes: Optional[pulumi.Input[str]] = None,
                 role_arn: Optional[pulumi.Input[str]] = None,
                 source_arn: Optional[pulumi.Input[str]] = None,
                 trigger_arn: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a CDN Fc Trigger resource.

        For information about CDN Fc Trigger and how to use it, see [What is Fc Trigger](https://www.alibabacloud.com/help/en/cdn/developer-reference/api-cdn-2018-05-10-addfctrigger).

        > **NOTE:** Available in v1.165.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.get_account()
        default_get_regions = alicloud.get_regions(current=True)
        example = alicloud.cdn.FcTrigger("example",
            event_meta_name="LogFileCreated",
            event_meta_version="1.0.0",
            notes="example_value",
            role_arn=f"acs:ram::{default.id}:role/aliyuncdneventnotificationrole",
            source_arn=f"acs:cdn:*:{default.id}:domain/example.com",
            trigger_arn=f"acs:fc:{default_get_regions.regions[0].id}:{default.id}:services/FCTestService/functions/printEvent/triggers/testtrigger")
        ```

        ## Import

        CDN Fc Trigger can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cdn/fcTrigger:FcTrigger example <trigger_arn>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] event_meta_name: The name of the Event.
        :param pulumi.Input[str] event_meta_version: The version of the Event.
        :param pulumi.Input[str] function_arn: The function arn. The value formats as `acs:fc:{RegionID}:{AccountID}:{Filter}`.
        :param pulumi.Input[str] notes: The Note information.
        :param pulumi.Input[str] role_arn: The role authorized by RAM. The value formats as `acs:ram::{AccountID}:role/{RoleName}`.
        :param pulumi.Input[str] source_arn: Resources and filters for event listening. The value formats as `acs:cdn:{RegionID}:{AccountID}:{Filter}`.
        :param pulumi.Input[str] trigger_arn: The trigger corresponding to the function Compute Service. The value formats as `acs:fc:{RegionID}:{AccountID}:{Filter}`. See [Create a CDN Fc Trigger](https://www.alibabacloud.com/help/en/cdn/developer-reference/api-cdn-2018-05-10-addfctrigger) for more details.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FcTriggerArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a CDN Fc Trigger resource.

        For information about CDN Fc Trigger and how to use it, see [What is Fc Trigger](https://www.alibabacloud.com/help/en/cdn/developer-reference/api-cdn-2018-05-10-addfctrigger).

        > **NOTE:** Available in v1.165.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.get_account()
        default_get_regions = alicloud.get_regions(current=True)
        example = alicloud.cdn.FcTrigger("example",
            event_meta_name="LogFileCreated",
            event_meta_version="1.0.0",
            notes="example_value",
            role_arn=f"acs:ram::{default.id}:role/aliyuncdneventnotificationrole",
            source_arn=f"acs:cdn:*:{default.id}:domain/example.com",
            trigger_arn=f"acs:fc:{default_get_regions.regions[0].id}:{default.id}:services/FCTestService/functions/printEvent/triggers/testtrigger")
        ```

        ## Import

        CDN Fc Trigger can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cdn/fcTrigger:FcTrigger example <trigger_arn>
        ```

        :param str resource_name: The name of the resource.
        :param FcTriggerArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FcTriggerArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 event_meta_name: Optional[pulumi.Input[str]] = None,
                 event_meta_version: Optional[pulumi.Input[str]] = None,
                 function_arn: Optional[pulumi.Input[str]] = None,
                 notes: Optional[pulumi.Input[str]] = None,
                 role_arn: Optional[pulumi.Input[str]] = None,
                 source_arn: Optional[pulumi.Input[str]] = None,
                 trigger_arn: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FcTriggerArgs.__new__(FcTriggerArgs)

            if event_meta_name is None and not opts.urn:
                raise TypeError("Missing required property 'event_meta_name'")
            __props__.__dict__["event_meta_name"] = event_meta_name
            if event_meta_version is None and not opts.urn:
                raise TypeError("Missing required property 'event_meta_version'")
            __props__.__dict__["event_meta_version"] = event_meta_version
            __props__.__dict__["function_arn"] = function_arn
            if notes is None and not opts.urn:
                raise TypeError("Missing required property 'notes'")
            __props__.__dict__["notes"] = notes
            if role_arn is None and not opts.urn:
                raise TypeError("Missing required property 'role_arn'")
            __props__.__dict__["role_arn"] = role_arn
            if source_arn is None and not opts.urn:
                raise TypeError("Missing required property 'source_arn'")
            __props__.__dict__["source_arn"] = source_arn
            if trigger_arn is None and not opts.urn:
                raise TypeError("Missing required property 'trigger_arn'")
            __props__.__dict__["trigger_arn"] = trigger_arn
        super(FcTrigger, __self__).__init__(
            'alicloud:cdn/fcTrigger:FcTrigger',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            event_meta_name: Optional[pulumi.Input[str]] = None,
            event_meta_version: Optional[pulumi.Input[str]] = None,
            function_arn: Optional[pulumi.Input[str]] = None,
            notes: Optional[pulumi.Input[str]] = None,
            role_arn: Optional[pulumi.Input[str]] = None,
            source_arn: Optional[pulumi.Input[str]] = None,
            trigger_arn: Optional[pulumi.Input[str]] = None) -> 'FcTrigger':
        """
        Get an existing FcTrigger resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] event_meta_name: The name of the Event.
        :param pulumi.Input[str] event_meta_version: The version of the Event.
        :param pulumi.Input[str] function_arn: The function arn. The value formats as `acs:fc:{RegionID}:{AccountID}:{Filter}`.
        :param pulumi.Input[str] notes: The Note information.
        :param pulumi.Input[str] role_arn: The role authorized by RAM. The value formats as `acs:ram::{AccountID}:role/{RoleName}`.
        :param pulumi.Input[str] source_arn: Resources and filters for event listening. The value formats as `acs:cdn:{RegionID}:{AccountID}:{Filter}`.
        :param pulumi.Input[str] trigger_arn: The trigger corresponding to the function Compute Service. The value formats as `acs:fc:{RegionID}:{AccountID}:{Filter}`. See [Create a CDN Fc Trigger](https://www.alibabacloud.com/help/en/cdn/developer-reference/api-cdn-2018-05-10-addfctrigger) for more details.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FcTriggerState.__new__(_FcTriggerState)

        __props__.__dict__["event_meta_name"] = event_meta_name
        __props__.__dict__["event_meta_version"] = event_meta_version
        __props__.__dict__["function_arn"] = function_arn
        __props__.__dict__["notes"] = notes
        __props__.__dict__["role_arn"] = role_arn
        __props__.__dict__["source_arn"] = source_arn
        __props__.__dict__["trigger_arn"] = trigger_arn
        return FcTrigger(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="eventMetaName")
    def event_meta_name(self) -> pulumi.Output[str]:
        """
        The name of the Event.
        """
        return pulumi.get(self, "event_meta_name")

    @property
    @pulumi.getter(name="eventMetaVersion")
    def event_meta_version(self) -> pulumi.Output[str]:
        """
        The version of the Event.
        """
        return pulumi.get(self, "event_meta_version")

    @property
    @pulumi.getter(name="functionArn")
    def function_arn(self) -> pulumi.Output[Optional[str]]:
        """
        The function arn. The value formats as `acs:fc:{RegionID}:{AccountID}:{Filter}`.
        """
        return pulumi.get(self, "function_arn")

    @property
    @pulumi.getter
    def notes(self) -> pulumi.Output[str]:
        """
        The Note information.
        """
        return pulumi.get(self, "notes")

    @property
    @pulumi.getter(name="roleArn")
    def role_arn(self) -> pulumi.Output[str]:
        """
        The role authorized by RAM. The value formats as `acs:ram::{AccountID}:role/{RoleName}`.
        """
        return pulumi.get(self, "role_arn")

    @property
    @pulumi.getter(name="sourceArn")
    def source_arn(self) -> pulumi.Output[str]:
        """
        Resources and filters for event listening. The value formats as `acs:cdn:{RegionID}:{AccountID}:{Filter}`.
        """
        return pulumi.get(self, "source_arn")

    @property
    @pulumi.getter(name="triggerArn")
    def trigger_arn(self) -> pulumi.Output[str]:
        """
        The trigger corresponding to the function Compute Service. The value formats as `acs:fc:{RegionID}:{AccountID}:{Filter}`. See [Create a CDN Fc Trigger](https://www.alibabacloud.com/help/en/cdn/developer-reference/api-cdn-2018-05-10-addfctrigger) for more details.
        """
        return pulumi.get(self, "trigger_arn")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['TrafficQosRuleArgs', 'TrafficQosRule']

@pulumi.input_type
class TrafficQosRuleArgs:
    def __init__(__self__, *,
                 priority: pulumi.Input[int],
                 protocol: pulumi.Input[str],
                 qos_id: pulumi.Input[str],
                 queue_id: pulumi.Input[str],
                 dst_cidr: Optional[pulumi.Input[str]] = None,
                 dst_ipv6_cidr: Optional[pulumi.Input[str]] = None,
                 dst_port_range: Optional[pulumi.Input[str]] = None,
                 match_dscp: Optional[pulumi.Input[int]] = None,
                 remarking_dscp: Optional[pulumi.Input[int]] = None,
                 rule_description: Optional[pulumi.Input[str]] = None,
                 rule_name: Optional[pulumi.Input[str]] = None,
                 src_cidr: Optional[pulumi.Input[str]] = None,
                 src_ipv6_cidr: Optional[pulumi.Input[str]] = None,
                 src_port_range: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a TrafficQosRule resource.
        :param pulumi.Input[int] priority: QoS rule priority. Value range: **1** to **9000**. The larger the number, the higher the priority. The priority of a QoS rule cannot be repeated in the same QoS policy.
        :param pulumi.Input[str] protocol: QoS rule protocol type, value:
               - **ALL**
               - **ICMP(IPv4)**
               - **ICMPv6(IPv6)* *
               - **TCP**
               - **UDP**
               - **GRE**
               - **SSH**
               - **Telnet**
               - **HTTP**
               - **HTTPS**
               - **MS SQL**
               - **Oracle**
               - **MySql**
               - **RDP**
               - **PostgreSQL**
               - **Redis**.
        :param pulumi.Input[str] qos_id: The QoS policy ID.
        :param pulumi.Input[str] queue_id: The QoS queue ID.
        :param pulumi.Input[str] dst_cidr: The traffic of the QoS rule matches the Destination IPv4 network segment.
               > **NOTE:**  If this parameter is not supported, enter **SrcIPv6Cidr** or **DstIPv6Cidr * *.
        :param pulumi.Input[str] dst_ipv6_cidr: The QoS rule traffic matches the Destination IPv6 network segment.
               > **NOTE:**  If this parameter is not supported, enter **SrcCidr** or **DstCidr * *.
        :param pulumi.Input[str] dst_port_range: QoS rule traffic matches the destination port number range. Value range: **0** to **65535**. If not, the value is - 1. Currently, only a single port number is supported, and the start and end of the port number must be the same. The corresponding destination port number range is fixed for different protocol types. The values are as follows:
               - **ALL**:-1/-1, not editable.
               - **ICMP(IPv4)**:-1/-1, non-editable.
               - **ICMPv6(IPv6)**:-1/-1, non-editable.
               - **TCP**:-1/-1, editable.
               - **UDP**:-1/-1, editable.
               - **GRE**:-1/-1, not editable.
               - **SSH**:22/22, not editable.
               - **Telnet**:23/23, not editable.
               - **HTTP**:80/80, non-editable.
               - **HTTPS**:443/443, which cannot be edited.
               - **MS SQL**:1443/1443, which cannot be edited.
               - **Oracle**:1521/1521, non-editable.
               - **MySql**:3306/3306, non-editable.
               - **RDP**:3389/3389, non-editable.
               - **PostgreSQL**:5432/5432, non-editable.
               - **Redis**:6379/6379, non-editable.
        :param pulumi.Input[int] match_dscp: The DSCP value of the traffic matched by the QoS rule. Value range: **0** to **63**. If not, the value is - 1.
        :param pulumi.Input[int] remarking_dscp: Modify The DSCP value in the flow. Value range: **0** to **63**. If the value is not modified, the value is - 1.
        :param pulumi.Input[str] rule_description: The description of the QoS rule.  The length is 0 to 256 characters and cannot start with 'http:// 'or 'https.
        :param pulumi.Input[str] rule_name: The name of the QoS rule.  The length is 0 to 128 characters and cannot start with 'http:// 'or 'https.
        :param pulumi.Input[str] src_cidr: The QoS rule traffic matches the source IPv4 CIDR block.
               > **NOTE:**  If this parameter is not supported, enter **SrcIPv6Cidr** or **DstIPv6Cidr * *.
        :param pulumi.Input[str] src_ipv6_cidr: The QoS rule traffic matches the source IPv6 network segment.
               > **NOTE:**  If this parameter is not supported, enter **SrcCidr** or **DstCidr * *.
        :param pulumi.Input[str] src_port_range: The source port number of the QoS rule traffic matching. The value range is **0** to **65535**. If the traffic does not match, the value is - 1. Currently, only a single port number is supported, and the start and end of the port number must be the same.
        """
        pulumi.set(__self__, "priority", priority)
        pulumi.set(__self__, "protocol", protocol)
        pulumi.set(__self__, "qos_id", qos_id)
        pulumi.set(__self__, "queue_id", queue_id)
        if dst_cidr is not None:
            pulumi.set(__self__, "dst_cidr", dst_cidr)
        if dst_ipv6_cidr is not None:
            pulumi.set(__self__, "dst_ipv6_cidr", dst_ipv6_cidr)
        if dst_port_range is not None:
            pulumi.set(__self__, "dst_port_range", dst_port_range)
        if match_dscp is not None:
            pulumi.set(__self__, "match_dscp", match_dscp)
        if remarking_dscp is not None:
            pulumi.set(__self__, "remarking_dscp", remarking_dscp)
        if rule_description is not None:
            pulumi.set(__self__, "rule_description", rule_description)
        if rule_name is not None:
            pulumi.set(__self__, "rule_name", rule_name)
        if src_cidr is not None:
            pulumi.set(__self__, "src_cidr", src_cidr)
        if src_ipv6_cidr is not None:
            pulumi.set(__self__, "src_ipv6_cidr", src_ipv6_cidr)
        if src_port_range is not None:
            pulumi.set(__self__, "src_port_range", src_port_range)

    @property
    @pulumi.getter
    def priority(self) -> pulumi.Input[int]:
        """
        QoS rule priority. Value range: **1** to **9000**. The larger the number, the higher the priority. The priority of a QoS rule cannot be repeated in the same QoS policy.
        """
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: pulumi.Input[int]):
        pulumi.set(self, "priority", value)

    @property
    @pulumi.getter
    def protocol(self) -> pulumi.Input[str]:
        """
        QoS rule protocol type, value:
        - **ALL**
        - **ICMP(IPv4)**
        - **ICMPv6(IPv6)* *
        - **TCP**
        - **UDP**
        - **GRE**
        - **SSH**
        - **Telnet**
        - **HTTP**
        - **HTTPS**
        - **MS SQL**
        - **Oracle**
        - **MySql**
        - **RDP**
        - **PostgreSQL**
        - **Redis**.
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: pulumi.Input[str]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter(name="qosId")
    def qos_id(self) -> pulumi.Input[str]:
        """
        The QoS policy ID.
        """
        return pulumi.get(self, "qos_id")

    @qos_id.setter
    def qos_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "qos_id", value)

    @property
    @pulumi.getter(name="queueId")
    def queue_id(self) -> pulumi.Input[str]:
        """
        The QoS queue ID.
        """
        return pulumi.get(self, "queue_id")

    @queue_id.setter
    def queue_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "queue_id", value)

    @property
    @pulumi.getter(name="dstCidr")
    def dst_cidr(self) -> Optional[pulumi.Input[str]]:
        """
        The traffic of the QoS rule matches the Destination IPv4 network segment.
        > **NOTE:**  If this parameter is not supported, enter **SrcIPv6Cidr** or **DstIPv6Cidr * *.
        """
        return pulumi.get(self, "dst_cidr")

    @dst_cidr.setter
    def dst_cidr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dst_cidr", value)

    @property
    @pulumi.getter(name="dstIpv6Cidr")
    def dst_ipv6_cidr(self) -> Optional[pulumi.Input[str]]:
        """
        The QoS rule traffic matches the Destination IPv6 network segment.
        > **NOTE:**  If this parameter is not supported, enter **SrcCidr** or **DstCidr * *.
        """
        return pulumi.get(self, "dst_ipv6_cidr")

    @dst_ipv6_cidr.setter
    def dst_ipv6_cidr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dst_ipv6_cidr", value)

    @property
    @pulumi.getter(name="dstPortRange")
    def dst_port_range(self) -> Optional[pulumi.Input[str]]:
        """
        QoS rule traffic matches the destination port number range. Value range: **0** to **65535**. If not, the value is - 1. Currently, only a single port number is supported, and the start and end of the port number must be the same. The corresponding destination port number range is fixed for different protocol types. The values are as follows:
        - **ALL**:-1/-1, not editable.
        - **ICMP(IPv4)**:-1/-1, non-editable.
        - **ICMPv6(IPv6)**:-1/-1, non-editable.
        - **TCP**:-1/-1, editable.
        - **UDP**:-1/-1, editable.
        - **GRE**:-1/-1, not editable.
        - **SSH**:22/22, not editable.
        - **Telnet**:23/23, not editable.
        - **HTTP**:80/80, non-editable.
        - **HTTPS**:443/443, which cannot be edited.
        - **MS SQL**:1443/1443, which cannot be edited.
        - **Oracle**:1521/1521, non-editable.
        - **MySql**:3306/3306, non-editable.
        - **RDP**:3389/3389, non-editable.
        - **PostgreSQL**:5432/5432, non-editable.
        - **Redis**:6379/6379, non-editable.
        """
        return pulumi.get(self, "dst_port_range")

    @dst_port_range.setter
    def dst_port_range(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dst_port_range", value)

    @property
    @pulumi.getter(name="matchDscp")
    def match_dscp(self) -> Optional[pulumi.Input[int]]:
        """
        The DSCP value of the traffic matched by the QoS rule. Value range: **0** to **63**. If not, the value is - 1.
        """
        return pulumi.get(self, "match_dscp")

    @match_dscp.setter
    def match_dscp(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "match_dscp", value)

    @property
    @pulumi.getter(name="remarkingDscp")
    def remarking_dscp(self) -> Optional[pulumi.Input[int]]:
        """
        Modify The DSCP value in the flow. Value range: **0** to **63**. If the value is not modified, the value is - 1.
        """
        return pulumi.get(self, "remarking_dscp")

    @remarking_dscp.setter
    def remarking_dscp(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "remarking_dscp", value)

    @property
    @pulumi.getter(name="ruleDescription")
    def rule_description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the QoS rule.  The length is 0 to 256 characters and cannot start with 'http:// 'or 'https.
        """
        return pulumi.get(self, "rule_description")

    @rule_description.setter
    def rule_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "rule_description", value)

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the QoS rule.  The length is 0 to 128 characters and cannot start with 'http:// 'or 'https.
        """
        return pulumi.get(self, "rule_name")

    @rule_name.setter
    def rule_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "rule_name", value)

    @property
    @pulumi.getter(name="srcCidr")
    def src_cidr(self) -> Optional[pulumi.Input[str]]:
        """
        The QoS rule traffic matches the source IPv4 CIDR block.
        > **NOTE:**  If this parameter is not supported, enter **SrcIPv6Cidr** or **DstIPv6Cidr * *.
        """
        return pulumi.get(self, "src_cidr")

    @src_cidr.setter
    def src_cidr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "src_cidr", value)

    @property
    @pulumi.getter(name="srcIpv6Cidr")
    def src_ipv6_cidr(self) -> Optional[pulumi.Input[str]]:
        """
        The QoS rule traffic matches the source IPv6 network segment.
        > **NOTE:**  If this parameter is not supported, enter **SrcCidr** or **DstCidr * *.
        """
        return pulumi.get(self, "src_ipv6_cidr")

    @src_ipv6_cidr.setter
    def src_ipv6_cidr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "src_ipv6_cidr", value)

    @property
    @pulumi.getter(name="srcPortRange")
    def src_port_range(self) -> Optional[pulumi.Input[str]]:
        """
        The source port number of the QoS rule traffic matching. The value range is **0** to **65535**. If the traffic does not match, the value is - 1. Currently, only a single port number is supported, and the start and end of the port number must be the same.
        """
        return pulumi.get(self, "src_port_range")

    @src_port_range.setter
    def src_port_range(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "src_port_range", value)


@pulumi.input_type
class _TrafficQosRuleState:
    def __init__(__self__, *,
                 dst_cidr: Optional[pulumi.Input[str]] = None,
                 dst_ipv6_cidr: Optional[pulumi.Input[str]] = None,
                 dst_port_range: Optional[pulumi.Input[str]] = None,
                 match_dscp: Optional[pulumi.Input[int]] = None,
                 priority: Optional[pulumi.Input[int]] = None,
                 protocol: Optional[pulumi.Input[str]] = None,
                 qos_id: Optional[pulumi.Input[str]] = None,
                 queue_id: Optional[pulumi.Input[str]] = None,
                 remarking_dscp: Optional[pulumi.Input[int]] = None,
                 rule_description: Optional[pulumi.Input[str]] = None,
                 rule_id: Optional[pulumi.Input[str]] = None,
                 rule_name: Optional[pulumi.Input[str]] = None,
                 src_cidr: Optional[pulumi.Input[str]] = None,
                 src_ipv6_cidr: Optional[pulumi.Input[str]] = None,
                 src_port_range: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering TrafficQosRule resources.
        :param pulumi.Input[str] dst_cidr: The traffic of the QoS rule matches the Destination IPv4 network segment.
               > **NOTE:**  If this parameter is not supported, enter **SrcIPv6Cidr** or **DstIPv6Cidr * *.
        :param pulumi.Input[str] dst_ipv6_cidr: The QoS rule traffic matches the Destination IPv6 network segment.
               > **NOTE:**  If this parameter is not supported, enter **SrcCidr** or **DstCidr * *.
        :param pulumi.Input[str] dst_port_range: QoS rule traffic matches the destination port number range. Value range: **0** to **65535**. If not, the value is - 1. Currently, only a single port number is supported, and the start and end of the port number must be the same. The corresponding destination port number range is fixed for different protocol types. The values are as follows:
               - **ALL**:-1/-1, not editable.
               - **ICMP(IPv4)**:-1/-1, non-editable.
               - **ICMPv6(IPv6)**:-1/-1, non-editable.
               - **TCP**:-1/-1, editable.
               - **UDP**:-1/-1, editable.
               - **GRE**:-1/-1, not editable.
               - **SSH**:22/22, not editable.
               - **Telnet**:23/23, not editable.
               - **HTTP**:80/80, non-editable.
               - **HTTPS**:443/443, which cannot be edited.
               - **MS SQL**:1443/1443, which cannot be edited.
               - **Oracle**:1521/1521, non-editable.
               - **MySql**:3306/3306, non-editable.
               - **RDP**:3389/3389, non-editable.
               - **PostgreSQL**:5432/5432, non-editable.
               - **Redis**:6379/6379, non-editable.
        :param pulumi.Input[int] match_dscp: The DSCP value of the traffic matched by the QoS rule. Value range: **0** to **63**. If not, the value is - 1.
        :param pulumi.Input[int] priority: QoS rule priority. Value range: **1** to **9000**. The larger the number, the higher the priority. The priority of a QoS rule cannot be repeated in the same QoS policy.
        :param pulumi.Input[str] protocol: QoS rule protocol type, value:
               - **ALL**
               - **ICMP(IPv4)**
               - **ICMPv6(IPv6)* *
               - **TCP**
               - **UDP**
               - **GRE**
               - **SSH**
               - **Telnet**
               - **HTTP**
               - **HTTPS**
               - **MS SQL**
               - **Oracle**
               - **MySql**
               - **RDP**
               - **PostgreSQL**
               - **Redis**.
        :param pulumi.Input[str] qos_id: The QoS policy ID.
        :param pulumi.Input[str] queue_id: The QoS queue ID.
        :param pulumi.Input[int] remarking_dscp: Modify The DSCP value in the flow. Value range: **0** to **63**. If the value is not modified, the value is - 1.
        :param pulumi.Input[str] rule_description: The description of the QoS rule.  The length is 0 to 256 characters and cannot start with 'http:// 'or 'https.
        :param pulumi.Input[str] rule_id: The ID of the QoS rule.
        :param pulumi.Input[str] rule_name: The name of the QoS rule.  The length is 0 to 128 characters and cannot start with 'http:// 'or 'https.
        :param pulumi.Input[str] src_cidr: The QoS rule traffic matches the source IPv4 CIDR block.
               > **NOTE:**  If this parameter is not supported, enter **SrcIPv6Cidr** or **DstIPv6Cidr * *.
        :param pulumi.Input[str] src_ipv6_cidr: The QoS rule traffic matches the source IPv6 network segment.
               > **NOTE:**  If this parameter is not supported, enter **SrcCidr** or **DstCidr * *.
        :param pulumi.Input[str] src_port_range: The source port number of the QoS rule traffic matching. The value range is **0** to **65535**. If the traffic does not match, the value is - 1. Currently, only a single port number is supported, and the start and end of the port number must be the same.
        :param pulumi.Input[str] status: The status of the QoS rule. Value:
        """
        if dst_cidr is not None:
            pulumi.set(__self__, "dst_cidr", dst_cidr)
        if dst_ipv6_cidr is not None:
            pulumi.set(__self__, "dst_ipv6_cidr", dst_ipv6_cidr)
        if dst_port_range is not None:
            pulumi.set(__self__, "dst_port_range", dst_port_range)
        if match_dscp is not None:
            pulumi.set(__self__, "match_dscp", match_dscp)
        if priority is not None:
            pulumi.set(__self__, "priority", priority)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if qos_id is not None:
            pulumi.set(__self__, "qos_id", qos_id)
        if queue_id is not None:
            pulumi.set(__self__, "queue_id", queue_id)
        if remarking_dscp is not None:
            pulumi.set(__self__, "remarking_dscp", remarking_dscp)
        if rule_description is not None:
            pulumi.set(__self__, "rule_description", rule_description)
        if rule_id is not None:
            pulumi.set(__self__, "rule_id", rule_id)
        if rule_name is not None:
            pulumi.set(__self__, "rule_name", rule_name)
        if src_cidr is not None:
            pulumi.set(__self__, "src_cidr", src_cidr)
        if src_ipv6_cidr is not None:
            pulumi.set(__self__, "src_ipv6_cidr", src_ipv6_cidr)
        if src_port_range is not None:
            pulumi.set(__self__, "src_port_range", src_port_range)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="dstCidr")
    def dst_cidr(self) -> Optional[pulumi.Input[str]]:
        """
        The traffic of the QoS rule matches the Destination IPv4 network segment.
        > **NOTE:**  If this parameter is not supported, enter **SrcIPv6Cidr** or **DstIPv6Cidr * *.
        """
        return pulumi.get(self, "dst_cidr")

    @dst_cidr.setter
    def dst_cidr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dst_cidr", value)

    @property
    @pulumi.getter(name="dstIpv6Cidr")
    def dst_ipv6_cidr(self) -> Optional[pulumi.Input[str]]:
        """
        The QoS rule traffic matches the Destination IPv6 network segment.
        > **NOTE:**  If this parameter is not supported, enter **SrcCidr** or **DstCidr * *.
        """
        return pulumi.get(self, "dst_ipv6_cidr")

    @dst_ipv6_cidr.setter
    def dst_ipv6_cidr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dst_ipv6_cidr", value)

    @property
    @pulumi.getter(name="dstPortRange")
    def dst_port_range(self) -> Optional[pulumi.Input[str]]:
        """
        QoS rule traffic matches the destination port number range. Value range: **0** to **65535**. If not, the value is - 1. Currently, only a single port number is supported, and the start and end of the port number must be the same. The corresponding destination port number range is fixed for different protocol types. The values are as follows:
        - **ALL**:-1/-1, not editable.
        - **ICMP(IPv4)**:-1/-1, non-editable.
        - **ICMPv6(IPv6)**:-1/-1, non-editable.
        - **TCP**:-1/-1, editable.
        - **UDP**:-1/-1, editable.
        - **GRE**:-1/-1, not editable.
        - **SSH**:22/22, not editable.
        - **Telnet**:23/23, not editable.
        - **HTTP**:80/80, non-editable.
        - **HTTPS**:443/443, which cannot be edited.
        - **MS SQL**:1443/1443, which cannot be edited.
        - **Oracle**:1521/1521, non-editable.
        - **MySql**:3306/3306, non-editable.
        - **RDP**:3389/3389, non-editable.
        - **PostgreSQL**:5432/5432, non-editable.
        - **Redis**:6379/6379, non-editable.
        """
        return pulumi.get(self, "dst_port_range")

    @dst_port_range.setter
    def dst_port_range(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dst_port_range", value)

    @property
    @pulumi.getter(name="matchDscp")
    def match_dscp(self) -> Optional[pulumi.Input[int]]:
        """
        The DSCP value of the traffic matched by the QoS rule. Value range: **0** to **63**. If not, the value is - 1.
        """
        return pulumi.get(self, "match_dscp")

    @match_dscp.setter
    def match_dscp(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "match_dscp", value)

    @property
    @pulumi.getter
    def priority(self) -> Optional[pulumi.Input[int]]:
        """
        QoS rule priority. Value range: **1** to **9000**. The larger the number, the higher the priority. The priority of a QoS rule cannot be repeated in the same QoS policy.
        """
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "priority", value)

    @property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[str]]:
        """
        QoS rule protocol type, value:
        - **ALL**
        - **ICMP(IPv4)**
        - **ICMPv6(IPv6)* *
        - **TCP**
        - **UDP**
        - **GRE**
        - **SSH**
        - **Telnet**
        - **HTTP**
        - **HTTPS**
        - **MS SQL**
        - **Oracle**
        - **MySql**
        - **RDP**
        - **PostgreSQL**
        - **Redis**.
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter(name="qosId")
    def qos_id(self) -> Optional[pulumi.Input[str]]:
        """
        The QoS policy ID.
        """
        return pulumi.get(self, "qos_id")

    @qos_id.setter
    def qos_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "qos_id", value)

    @property
    @pulumi.getter(name="queueId")
    def queue_id(self) -> Optional[pulumi.Input[str]]:
        """
        The QoS queue ID.
        """
        return pulumi.get(self, "queue_id")

    @queue_id.setter
    def queue_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "queue_id", value)

    @property
    @pulumi.getter(name="remarkingDscp")
    def remarking_dscp(self) -> Optional[pulumi.Input[int]]:
        """
        Modify The DSCP value in the flow. Value range: **0** to **63**. If the value is not modified, the value is - 1.
        """
        return pulumi.get(self, "remarking_dscp")

    @remarking_dscp.setter
    def remarking_dscp(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "remarking_dscp", value)

    @property
    @pulumi.getter(name="ruleDescription")
    def rule_description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the QoS rule.  The length is 0 to 256 characters and cannot start with 'http:// 'or 'https.
        """
        return pulumi.get(self, "rule_description")

    @rule_description.setter
    def rule_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "rule_description", value)

    @property
    @pulumi.getter(name="ruleId")
    def rule_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the QoS rule.
        """
        return pulumi.get(self, "rule_id")

    @rule_id.setter
    def rule_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "rule_id", value)

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the QoS rule.  The length is 0 to 128 characters and cannot start with 'http:// 'or 'https.
        """
        return pulumi.get(self, "rule_name")

    @rule_name.setter
    def rule_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "rule_name", value)

    @property
    @pulumi.getter(name="srcCidr")
    def src_cidr(self) -> Optional[pulumi.Input[str]]:
        """
        The QoS rule traffic matches the source IPv4 CIDR block.
        > **NOTE:**  If this parameter is not supported, enter **SrcIPv6Cidr** or **DstIPv6Cidr * *.
        """
        return pulumi.get(self, "src_cidr")

    @src_cidr.setter
    def src_cidr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "src_cidr", value)

    @property
    @pulumi.getter(name="srcIpv6Cidr")
    def src_ipv6_cidr(self) -> Optional[pulumi.Input[str]]:
        """
        The QoS rule traffic matches the source IPv6 network segment.
        > **NOTE:**  If this parameter is not supported, enter **SrcCidr** or **DstCidr * *.
        """
        return pulumi.get(self, "src_ipv6_cidr")

    @src_ipv6_cidr.setter
    def src_ipv6_cidr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "src_ipv6_cidr", value)

    @property
    @pulumi.getter(name="srcPortRange")
    def src_port_range(self) -> Optional[pulumi.Input[str]]:
        """
        The source port number of the QoS rule traffic matching. The value range is **0** to **65535**. If the traffic does not match, the value is - 1. Currently, only a single port number is supported, and the start and end of the port number must be the same.
        """
        return pulumi.get(self, "src_port_range")

    @src_port_range.setter
    def src_port_range(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "src_port_range", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the QoS rule. Value:
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


class TrafficQosRule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dst_cidr: Optional[pulumi.Input[str]] = None,
                 dst_ipv6_cidr: Optional[pulumi.Input[str]] = None,
                 dst_port_range: Optional[pulumi.Input[str]] = None,
                 match_dscp: Optional[pulumi.Input[int]] = None,
                 priority: Optional[pulumi.Input[int]] = None,
                 protocol: Optional[pulumi.Input[str]] = None,
                 qos_id: Optional[pulumi.Input[str]] = None,
                 queue_id: Optional[pulumi.Input[str]] = None,
                 remarking_dscp: Optional[pulumi.Input[int]] = None,
                 rule_description: Optional[pulumi.Input[str]] = None,
                 rule_name: Optional[pulumi.Input[str]] = None,
                 src_cidr: Optional[pulumi.Input[str]] = None,
                 src_ipv6_cidr: Optional[pulumi.Input[str]] = None,
                 src_port_range: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Express Connect Traffic Qos Rule resource. Express Connect Traffic QoS Rule.

        For information about Express Connect Traffic Qos Rule and how to use it, see [What is Traffic Qos Rule](https://next.api.alibabacloud.com/document/Vpc/2016-04-28/CreateExpressConnectTrafficQosRule).

        > **NOTE:** Available since v1.224.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.expressconnect.get_physical_connections(name_regex="preserved-NODELETING")
        create_qos = alicloud.expressconnect.TrafficQos("createQos",
            qos_name=name,
            qos_description="terraform-example")
        associate_qos = alicloud.expressconnect.TrafficQosAssociation("associateQos",
            instance_id=default.ids[1],
            qos_id=create_qos.id,
            instance_type="PHYSICALCONNECTION")
        create_qos_queue = alicloud.expressconnect.TrafficQosQueue("createQosQueue",
            qos_id=create_qos.id,
            bandwidth_percent="60",
            queue_description="terraform-example",
            queue_name=name,
            queue_type="Medium")
        default_traffic_qos_rule = alicloud.expressconnect.TrafficQosRule("default",
            rule_description="terraform-example",
            priority=1,
            protocol="ALL",
            src_port_range="-1/-1",
            dst_ipv6_cidr="2001:db8:1234:5678::/64",
            src_ipv6_cidr="2001:db8:1234:5678::/64",
            dst_port_range="-1/-1",
            remarking_dscp=-1,
            queue_id=create_qos_queue.queue_id,
            qos_id=create_qos.id,
            match_dscp=-1,
            rule_name=name)
        ```

        ## Import

        Express Connect Traffic Qos Rule can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:expressconnect/trafficQosRule:TrafficQosRule example <qos_id>:<queue_id>:<rule_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] dst_cidr: The traffic of the QoS rule matches the Destination IPv4 network segment.
               > **NOTE:**  If this parameter is not supported, enter **SrcIPv6Cidr** or **DstIPv6Cidr * *.
        :param pulumi.Input[str] dst_ipv6_cidr: The QoS rule traffic matches the Destination IPv6 network segment.
               > **NOTE:**  If this parameter is not supported, enter **SrcCidr** or **DstCidr * *.
        :param pulumi.Input[str] dst_port_range: QoS rule traffic matches the destination port number range. Value range: **0** to **65535**. If not, the value is - 1. Currently, only a single port number is supported, and the start and end of the port number must be the same. The corresponding destination port number range is fixed for different protocol types. The values are as follows:
               - **ALL**:-1/-1, not editable.
               - **ICMP(IPv4)**:-1/-1, non-editable.
               - **ICMPv6(IPv6)**:-1/-1, non-editable.
               - **TCP**:-1/-1, editable.
               - **UDP**:-1/-1, editable.
               - **GRE**:-1/-1, not editable.
               - **SSH**:22/22, not editable.
               - **Telnet**:23/23, not editable.
               - **HTTP**:80/80, non-editable.
               - **HTTPS**:443/443, which cannot be edited.
               - **MS SQL**:1443/1443, which cannot be edited.
               - **Oracle**:1521/1521, non-editable.
               - **MySql**:3306/3306, non-editable.
               - **RDP**:3389/3389, non-editable.
               - **PostgreSQL**:5432/5432, non-editable.
               - **Redis**:6379/6379, non-editable.
        :param pulumi.Input[int] match_dscp: The DSCP value of the traffic matched by the QoS rule. Value range: **0** to **63**. If not, the value is - 1.
        :param pulumi.Input[int] priority: QoS rule priority. Value range: **1** to **9000**. The larger the number, the higher the priority. The priority of a QoS rule cannot be repeated in the same QoS policy.
        :param pulumi.Input[str] protocol: QoS rule protocol type, value:
               - **ALL**
               - **ICMP(IPv4)**
               - **ICMPv6(IPv6)* *
               - **TCP**
               - **UDP**
               - **GRE**
               - **SSH**
               - **Telnet**
               - **HTTP**
               - **HTTPS**
               - **MS SQL**
               - **Oracle**
               - **MySql**
               - **RDP**
               - **PostgreSQL**
               - **Redis**.
        :param pulumi.Input[str] qos_id: The QoS policy ID.
        :param pulumi.Input[str] queue_id: The QoS queue ID.
        :param pulumi.Input[int] remarking_dscp: Modify The DSCP value in the flow. Value range: **0** to **63**. If the value is not modified, the value is - 1.
        :param pulumi.Input[str] rule_description: The description of the QoS rule.  The length is 0 to 256 characters and cannot start with 'http:// 'or 'https.
        :param pulumi.Input[str] rule_name: The name of the QoS rule.  The length is 0 to 128 characters and cannot start with 'http:// 'or 'https.
        :param pulumi.Input[str] src_cidr: The QoS rule traffic matches the source IPv4 CIDR block.
               > **NOTE:**  If this parameter is not supported, enter **SrcIPv6Cidr** or **DstIPv6Cidr * *.
        :param pulumi.Input[str] src_ipv6_cidr: The QoS rule traffic matches the source IPv6 network segment.
               > **NOTE:**  If this parameter is not supported, enter **SrcCidr** or **DstCidr * *.
        :param pulumi.Input[str] src_port_range: The source port number of the QoS rule traffic matching. The value range is **0** to **65535**. If the traffic does not match, the value is - 1. Currently, only a single port number is supported, and the start and end of the port number must be the same.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TrafficQosRuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Express Connect Traffic Qos Rule resource. Express Connect Traffic QoS Rule.

        For information about Express Connect Traffic Qos Rule and how to use it, see [What is Traffic Qos Rule](https://next.api.alibabacloud.com/document/Vpc/2016-04-28/CreateExpressConnectTrafficQosRule).

        > **NOTE:** Available since v1.224.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.expressconnect.get_physical_connections(name_regex="preserved-NODELETING")
        create_qos = alicloud.expressconnect.TrafficQos("createQos",
            qos_name=name,
            qos_description="terraform-example")
        associate_qos = alicloud.expressconnect.TrafficQosAssociation("associateQos",
            instance_id=default.ids[1],
            qos_id=create_qos.id,
            instance_type="PHYSICALCONNECTION")
        create_qos_queue = alicloud.expressconnect.TrafficQosQueue("createQosQueue",
            qos_id=create_qos.id,
            bandwidth_percent="60",
            queue_description="terraform-example",
            queue_name=name,
            queue_type="Medium")
        default_traffic_qos_rule = alicloud.expressconnect.TrafficQosRule("default",
            rule_description="terraform-example",
            priority=1,
            protocol="ALL",
            src_port_range="-1/-1",
            dst_ipv6_cidr="2001:db8:1234:5678::/64",
            src_ipv6_cidr="2001:db8:1234:5678::/64",
            dst_port_range="-1/-1",
            remarking_dscp=-1,
            queue_id=create_qos_queue.queue_id,
            qos_id=create_qos.id,
            match_dscp=-1,
            rule_name=name)
        ```

        ## Import

        Express Connect Traffic Qos Rule can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:expressconnect/trafficQosRule:TrafficQosRule example <qos_id>:<queue_id>:<rule_id>
        ```

        :param str resource_name: The name of the resource.
        :param TrafficQosRuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TrafficQosRuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dst_cidr: Optional[pulumi.Input[str]] = None,
                 dst_ipv6_cidr: Optional[pulumi.Input[str]] = None,
                 dst_port_range: Optional[pulumi.Input[str]] = None,
                 match_dscp: Optional[pulumi.Input[int]] = None,
                 priority: Optional[pulumi.Input[int]] = None,
                 protocol: Optional[pulumi.Input[str]] = None,
                 qos_id: Optional[pulumi.Input[str]] = None,
                 queue_id: Optional[pulumi.Input[str]] = None,
                 remarking_dscp: Optional[pulumi.Input[int]] = None,
                 rule_description: Optional[pulumi.Input[str]] = None,
                 rule_name: Optional[pulumi.Input[str]] = None,
                 src_cidr: Optional[pulumi.Input[str]] = None,
                 src_ipv6_cidr: Optional[pulumi.Input[str]] = None,
                 src_port_range: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TrafficQosRuleArgs.__new__(TrafficQosRuleArgs)

            __props__.__dict__["dst_cidr"] = dst_cidr
            __props__.__dict__["dst_ipv6_cidr"] = dst_ipv6_cidr
            __props__.__dict__["dst_port_range"] = dst_port_range
            __props__.__dict__["match_dscp"] = match_dscp
            if priority is None and not opts.urn:
                raise TypeError("Missing required property 'priority'")
            __props__.__dict__["priority"] = priority
            if protocol is None and not opts.urn:
                raise TypeError("Missing required property 'protocol'")
            __props__.__dict__["protocol"] = protocol
            if qos_id is None and not opts.urn:
                raise TypeError("Missing required property 'qos_id'")
            __props__.__dict__["qos_id"] = qos_id
            if queue_id is None and not opts.urn:
                raise TypeError("Missing required property 'queue_id'")
            __props__.__dict__["queue_id"] = queue_id
            __props__.__dict__["remarking_dscp"] = remarking_dscp
            __props__.__dict__["rule_description"] = rule_description
            __props__.__dict__["rule_name"] = rule_name
            __props__.__dict__["src_cidr"] = src_cidr
            __props__.__dict__["src_ipv6_cidr"] = src_ipv6_cidr
            __props__.__dict__["src_port_range"] = src_port_range
            __props__.__dict__["rule_id"] = None
            __props__.__dict__["status"] = None
        super(TrafficQosRule, __self__).__init__(
            'alicloud:expressconnect/trafficQosRule:TrafficQosRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            dst_cidr: Optional[pulumi.Input[str]] = None,
            dst_ipv6_cidr: Optional[pulumi.Input[str]] = None,
            dst_port_range: Optional[pulumi.Input[str]] = None,
            match_dscp: Optional[pulumi.Input[int]] = None,
            priority: Optional[pulumi.Input[int]] = None,
            protocol: Optional[pulumi.Input[str]] = None,
            qos_id: Optional[pulumi.Input[str]] = None,
            queue_id: Optional[pulumi.Input[str]] = None,
            remarking_dscp: Optional[pulumi.Input[int]] = None,
            rule_description: Optional[pulumi.Input[str]] = None,
            rule_id: Optional[pulumi.Input[str]] = None,
            rule_name: Optional[pulumi.Input[str]] = None,
            src_cidr: Optional[pulumi.Input[str]] = None,
            src_ipv6_cidr: Optional[pulumi.Input[str]] = None,
            src_port_range: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None) -> 'TrafficQosRule':
        """
        Get an existing TrafficQosRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] dst_cidr: The traffic of the QoS rule matches the Destination IPv4 network segment.
               > **NOTE:**  If this parameter is not supported, enter **SrcIPv6Cidr** or **DstIPv6Cidr * *.
        :param pulumi.Input[str] dst_ipv6_cidr: The QoS rule traffic matches the Destination IPv6 network segment.
               > **NOTE:**  If this parameter is not supported, enter **SrcCidr** or **DstCidr * *.
        :param pulumi.Input[str] dst_port_range: QoS rule traffic matches the destination port number range. Value range: **0** to **65535**. If not, the value is - 1. Currently, only a single port number is supported, and the start and end of the port number must be the same. The corresponding destination port number range is fixed for different protocol types. The values are as follows:
               - **ALL**:-1/-1, not editable.
               - **ICMP(IPv4)**:-1/-1, non-editable.
               - **ICMPv6(IPv6)**:-1/-1, non-editable.
               - **TCP**:-1/-1, editable.
               - **UDP**:-1/-1, editable.
               - **GRE**:-1/-1, not editable.
               - **SSH**:22/22, not editable.
               - **Telnet**:23/23, not editable.
               - **HTTP**:80/80, non-editable.
               - **HTTPS**:443/443, which cannot be edited.
               - **MS SQL**:1443/1443, which cannot be edited.
               - **Oracle**:1521/1521, non-editable.
               - **MySql**:3306/3306, non-editable.
               - **RDP**:3389/3389, non-editable.
               - **PostgreSQL**:5432/5432, non-editable.
               - **Redis**:6379/6379, non-editable.
        :param pulumi.Input[int] match_dscp: The DSCP value of the traffic matched by the QoS rule. Value range: **0** to **63**. If not, the value is - 1.
        :param pulumi.Input[int] priority: QoS rule priority. Value range: **1** to **9000**. The larger the number, the higher the priority. The priority of a QoS rule cannot be repeated in the same QoS policy.
        :param pulumi.Input[str] protocol: QoS rule protocol type, value:
               - **ALL**
               - **ICMP(IPv4)**
               - **ICMPv6(IPv6)* *
               - **TCP**
               - **UDP**
               - **GRE**
               - **SSH**
               - **Telnet**
               - **HTTP**
               - **HTTPS**
               - **MS SQL**
               - **Oracle**
               - **MySql**
               - **RDP**
               - **PostgreSQL**
               - **Redis**.
        :param pulumi.Input[str] qos_id: The QoS policy ID.
        :param pulumi.Input[str] queue_id: The QoS queue ID.
        :param pulumi.Input[int] remarking_dscp: Modify The DSCP value in the flow. Value range: **0** to **63**. If the value is not modified, the value is - 1.
        :param pulumi.Input[str] rule_description: The description of the QoS rule.  The length is 0 to 256 characters and cannot start with 'http:// 'or 'https.
        :param pulumi.Input[str] rule_id: The ID of the QoS rule.
        :param pulumi.Input[str] rule_name: The name of the QoS rule.  The length is 0 to 128 characters and cannot start with 'http:// 'or 'https.
        :param pulumi.Input[str] src_cidr: The QoS rule traffic matches the source IPv4 CIDR block.
               > **NOTE:**  If this parameter is not supported, enter **SrcIPv6Cidr** or **DstIPv6Cidr * *.
        :param pulumi.Input[str] src_ipv6_cidr: The QoS rule traffic matches the source IPv6 network segment.
               > **NOTE:**  If this parameter is not supported, enter **SrcCidr** or **DstCidr * *.
        :param pulumi.Input[str] src_port_range: The source port number of the QoS rule traffic matching. The value range is **0** to **65535**. If the traffic does not match, the value is - 1. Currently, only a single port number is supported, and the start and end of the port number must be the same.
        :param pulumi.Input[str] status: The status of the QoS rule. Value:
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TrafficQosRuleState.__new__(_TrafficQosRuleState)

        __props__.__dict__["dst_cidr"] = dst_cidr
        __props__.__dict__["dst_ipv6_cidr"] = dst_ipv6_cidr
        __props__.__dict__["dst_port_range"] = dst_port_range
        __props__.__dict__["match_dscp"] = match_dscp
        __props__.__dict__["priority"] = priority
        __props__.__dict__["protocol"] = protocol
        __props__.__dict__["qos_id"] = qos_id
        __props__.__dict__["queue_id"] = queue_id
        __props__.__dict__["remarking_dscp"] = remarking_dscp
        __props__.__dict__["rule_description"] = rule_description
        __props__.__dict__["rule_id"] = rule_id
        __props__.__dict__["rule_name"] = rule_name
        __props__.__dict__["src_cidr"] = src_cidr
        __props__.__dict__["src_ipv6_cidr"] = src_ipv6_cidr
        __props__.__dict__["src_port_range"] = src_port_range
        __props__.__dict__["status"] = status
        return TrafficQosRule(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="dstCidr")
    def dst_cidr(self) -> pulumi.Output[Optional[str]]:
        """
        The traffic of the QoS rule matches the Destination IPv4 network segment.
        > **NOTE:**  If this parameter is not supported, enter **SrcIPv6Cidr** or **DstIPv6Cidr * *.
        """
        return pulumi.get(self, "dst_cidr")

    @property
    @pulumi.getter(name="dstIpv6Cidr")
    def dst_ipv6_cidr(self) -> pulumi.Output[Optional[str]]:
        """
        The QoS rule traffic matches the Destination IPv6 network segment.
        > **NOTE:**  If this parameter is not supported, enter **SrcCidr** or **DstCidr * *.
        """
        return pulumi.get(self, "dst_ipv6_cidr")

    @property
    @pulumi.getter(name="dstPortRange")
    def dst_port_range(self) -> pulumi.Output[str]:
        """
        QoS rule traffic matches the destination port number range. Value range: **0** to **65535**. If not, the value is - 1. Currently, only a single port number is supported, and the start and end of the port number must be the same. The corresponding destination port number range is fixed for different protocol types. The values are as follows:
        - **ALL**:-1/-1, not editable.
        - **ICMP(IPv4)**:-1/-1, non-editable.
        - **ICMPv6(IPv6)**:-1/-1, non-editable.
        - **TCP**:-1/-1, editable.
        - **UDP**:-1/-1, editable.
        - **GRE**:-1/-1, not editable.
        - **SSH**:22/22, not editable.
        - **Telnet**:23/23, not editable.
        - **HTTP**:80/80, non-editable.
        - **HTTPS**:443/443, which cannot be edited.
        - **MS SQL**:1443/1443, which cannot be edited.
        - **Oracle**:1521/1521, non-editable.
        - **MySql**:3306/3306, non-editable.
        - **RDP**:3389/3389, non-editable.
        - **PostgreSQL**:5432/5432, non-editable.
        - **Redis**:6379/6379, non-editable.
        """
        return pulumi.get(self, "dst_port_range")

    @property
    @pulumi.getter(name="matchDscp")
    def match_dscp(self) -> pulumi.Output[int]:
        """
        The DSCP value of the traffic matched by the QoS rule. Value range: **0** to **63**. If not, the value is - 1.
        """
        return pulumi.get(self, "match_dscp")

    @property
    @pulumi.getter
    def priority(self) -> pulumi.Output[int]:
        """
        QoS rule priority. Value range: **1** to **9000**. The larger the number, the higher the priority. The priority of a QoS rule cannot be repeated in the same QoS policy.
        """
        return pulumi.get(self, "priority")

    @property
    @pulumi.getter
    def protocol(self) -> pulumi.Output[str]:
        """
        QoS rule protocol type, value:
        - **ALL**
        - **ICMP(IPv4)**
        - **ICMPv6(IPv6)* *
        - **TCP**
        - **UDP**
        - **GRE**
        - **SSH**
        - **Telnet**
        - **HTTP**
        - **HTTPS**
        - **MS SQL**
        - **Oracle**
        - **MySql**
        - **RDP**
        - **PostgreSQL**
        - **Redis**.
        """
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter(name="qosId")
    def qos_id(self) -> pulumi.Output[str]:
        """
        The QoS policy ID.
        """
        return pulumi.get(self, "qos_id")

    @property
    @pulumi.getter(name="queueId")
    def queue_id(self) -> pulumi.Output[str]:
        """
        The QoS queue ID.
        """
        return pulumi.get(self, "queue_id")

    @property
    @pulumi.getter(name="remarkingDscp")
    def remarking_dscp(self) -> pulumi.Output[int]:
        """
        Modify The DSCP value in the flow. Value range: **0** to **63**. If the value is not modified, the value is - 1.
        """
        return pulumi.get(self, "remarking_dscp")

    @property
    @pulumi.getter(name="ruleDescription")
    def rule_description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of the QoS rule.  The length is 0 to 256 characters and cannot start with 'http:// 'or 'https.
        """
        return pulumi.get(self, "rule_description")

    @property
    @pulumi.getter(name="ruleId")
    def rule_id(self) -> pulumi.Output[str]:
        """
        The ID of the QoS rule.
        """
        return pulumi.get(self, "rule_id")

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> pulumi.Output[Optional[str]]:
        """
        The name of the QoS rule.  The length is 0 to 128 characters and cannot start with 'http:// 'or 'https.
        """
        return pulumi.get(self, "rule_name")

    @property
    @pulumi.getter(name="srcCidr")
    def src_cidr(self) -> pulumi.Output[Optional[str]]:
        """
        The QoS rule traffic matches the source IPv4 CIDR block.
        > **NOTE:**  If this parameter is not supported, enter **SrcIPv6Cidr** or **DstIPv6Cidr * *.
        """
        return pulumi.get(self, "src_cidr")

    @property
    @pulumi.getter(name="srcIpv6Cidr")
    def src_ipv6_cidr(self) -> pulumi.Output[Optional[str]]:
        """
        The QoS rule traffic matches the source IPv6 network segment.
        > **NOTE:**  If this parameter is not supported, enter **SrcCidr** or **DstCidr * *.
        """
        return pulumi.get(self, "src_ipv6_cidr")

    @property
    @pulumi.getter(name="srcPortRange")
    def src_port_range(self) -> pulumi.Output[str]:
        """
        The source port number of the QoS rule traffic matching. The value range is **0** to **65535**. If the traffic does not match, the value is - 1. Currently, only a single port number is supported, and the start and end of the port number must be the same.
        """
        return pulumi.get(self, "src_port_range")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the QoS rule. Value:
        """
        return pulumi.get(self, "status")

